@@ -1,13 +1,12 @@
 //===----------------------------------------------------------------------===//
 //
-//                     The LLVM Compiler Infrastructure
-//
-// This file is dual licensed under the MIT and the University of Illinois Open
-// Source Licenses. See LICENSE.TXT for details.
+// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
+// See https://llvm.org/LICENSE.txt for license information.
+// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 //
 //===----------------------------------------------------------------------===//
 //
-// XFAIL: c++98, c++03, c++11
+// XFAIL: c++03, c++11
 
 // <map>
 
@@ -20,20 +19,28 @@
 // equal_range shall not participate in overload resolution unless the
 // qualified-id Compare::is_transparent is valid and denotes a type
 
-
 #include <map>
 #include <cassert>
 
+#include "test_macros.h"
 #include "is_transparent.h"
 
-int main()
-{
-    {
+int main(int, char**) {
+  {
     typedef std::multimap<int, double, transparent_less> M;
-    M().find(C2Int{5});
-    }
-    {
+    M example;
+    assert(example.find(C2Int{5}) == example.end());
+  }
+  {
     typedef std::multimap<int, double, transparent_less_not_referenceable> M;
-    M().find(C2Int{5});
-    }
+    M example;
+    assert(example.find(C2Int{5}) == example.end());
+  }
+  {
+    using M = std::multimap<int, double, transparent_less_nonempty>;
+    M example;
+    assert(example.find(C2Int{5}) == example.end());
+  }
+
+  return 0;
 }
