@@ -10,7 +10,7 @@
 
 // class forward_list
 
-// allocator_type get_allocator() const
+// allocator_type get_allocator() const // constexpr since C++26
 
 #include <forward_list>
 #include <cassert>
@@ -18,17 +18,26 @@
 #include "test_allocator.h"
 #include "test_macros.h"
 
-int main(int, char**) {
-    {
-        std::allocator<int> alloc;
-        const std::forward_list<int> fl(alloc);
-        assert(fl.get_allocator() == alloc);
-    }
-    {
-        other_allocator<int> alloc(1);
-        const std::forward_list<int, other_allocator<int> > fl(alloc);
-        assert(fl.get_allocator() == alloc);
-    }
+TEST_CONSTEXPR_CXX26 bool test() {
+  {
+    std::allocator<int> alloc;
+    const std::forward_list<int> fl(alloc);
+    assert(fl.get_allocator() == alloc);
+  }
+  {
+    other_allocator<int> alloc(1);
+    const std::forward_list<int, other_allocator<int> > fl(alloc);
+    assert(fl.get_allocator() == alloc);
+  }
 
-    return 0;
+  return true;
+}
+
+int main(int, char**) {
+  assert(test());
+#if TEST_STD_VER >= 26
+  static_assert(test());
+#endif
+
+  return 0;
 }
